@@ -7,7 +7,11 @@ models.py - Model (and hence database) definitions. This is the core of the
             helpdesk structure.
 """
 
-from django.contrib.auth.models import User
+try:
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
+except ImportError:
+    from django.contrib.auth.models import User
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _, ugettext
@@ -17,11 +21,6 @@ try:
 except ImportError:
     from datetime import datetime as timezone
 
-from helpdesk.settings import HAS_TAG_SUPPORT
-
-if HAS_TAG_SUPPORT:
-    from tagging.fields import TagField
-
 class Queue(models.Model):
     """
     A queue is a collection of tickets into what would generally be business
@@ -441,14 +440,12 @@ class Ticket(models.Model):
         return TicketDependency.objects.filter(ticket=self).filter(depends_on__status__in=OPEN_STATUSES).count() == 0
     can_be_resolved = property(_can_be_resolved)
 
-    if HAS_TAG_SUPPORT:
-        tags = TagField(blank=True)
-
     class Meta:
         get_latest_by = "created"
+        ordering = ('id',)
 
     def __unicode__(self):
-        return u'%s' % self.title
+        return u'%s %s' % (self.id, self.title)
 
     def get_absolute_url(self):
         return ('helpdesk_view', (self.id,))
@@ -604,8 +601,9 @@ def attachment_path(instance, filename):
     os.umask(0)
     path = 'helpdesk/attachments/%s/%s' % (instance.followup.ticket.ticket_for_url, instance.followup.id )
     att_path = os.path.join(settings.MEDIA_ROOT, path)
-    if not os.path.exists(att_path):
-        os.makedirs(att_path, 0777)
+    if settings.DEFAULT_FILE_STORAGE == "django.core.files.storage.FileSystemStorage":
+        if not os.path.exists(att_path):
+            os.makedirs(att_path, 0777)
     return os.path.join(path, filename)
 
 
@@ -1196,6 +1194,7 @@ class CustomField(models.Model):
         
     empty_selection_list = models.BooleanField(
         _('Add empty first choice to List?'),
+        default=False,
         help_text=_('Only for List: adds an empty first entry to the choices list, which enforces that the user makes an active choice.'),
         )        
 
