@@ -13,7 +13,11 @@ through templates/helpdesk/help_api.html.
 
 from django import forms
 from django.contrib.auth import authenticate
-from django.contrib.auth.models import User
+try:
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
+except ImportError:
+    from django.contrib.auth.models import User
 from django.http import HttpResponse
 from django.shortcuts import render_to_response
 from django.template import loader, Context
