@@ -11,7 +11,11 @@ from datetime import datetime, timedelta
 import sys
 
 from django.conf import settings
-from django.contrib.auth.models import User
+try:
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
+except ImportError:
+    from django.contrib.auth.models import User
 from django.contrib.auth.decorators import login_required, user_passes_test
 from django.core.files.base import ContentFile
 from django.core.urlresolvers import reverse
@@ -34,12 +38,8 @@ except ImportError:
 from helpdesk.forms import TicketForm, UserSettingsForm, EmailIgnoreForm, EditTicketForm, TicketCCForm, EditFollowUpForm, TicketDependencyForm
 from helpdesk.lib import send_templated_mail, query_to_dict, apply_query, safe_template_context
 from helpdesk.models import Ticket, Queue, FollowUp, TicketChange, PreSetReply, Attachment, SavedSearch, IgnoreEmail, TicketCC, TicketDependency
-from helpdesk.settings import HAS_TAG_SUPPORT
 from helpdesk import settings as helpdesk_settings
   
-if HAS_TAG_SUPPORT:
-    from tagging.models import Tag, TaggedItem
-
 if helpdesk_settings.HELPDESK_ALLOW_NON_STAFF_TICKET_UPDATE:
     # treat 'normal' users like 'staff'
     staff_member_required = user_passes_test(lambda u: u.is_authenticated() and u.is_active)
@@ -86,10 +86,7 @@ def dashboard(request):
             submitter_email=email_current_user,
         ).order_by('status')
 
-    # calculate basic ticket stats if requested
-    basic_ticket_stats = False
-    if helpdesk_settings.HELPDESK_DASHBOARD_BASIC_TICKET_STATS:
-        basic_ticket_stats = calc_basic_ticket_stats(Ticket)
+    basic_ticket_stats = calc_basic_ticket_stats(Ticket)
 
     # The following query builds a grid of queues & ticket statuses,
     # to be displayed to the user. EG:
@@ -98,33 +95,18 @@ def dashboard(request):
     # Queue 2     4    12
 
     cursor = connection.cursor()
-    if helpdesk_settings.HELPDESK_DASHBOARD_HIDE_EMPTY_QUEUES:
-        cursor.execute("""
-            SELECT      q.id as queue,
-                        q.title AS name,
-                        COUNT(CASE t.status WHEN '1' THEN t.id WHEN '2' THEN t.id END) AS open,
-                        COUNT(CASE t.status WHEN '3' THEN t.id END) AS resolved,
-                        COUNT(CASE t.status WHEN '4' THEN t.id END) AS closed
-                FROM    helpdesk_ticket t,
-                        helpdesk_queue q
-                WHERE   q.id = t.queue_id
-                GROUP BY queue, name
-                ORDER BY q.id;
-        """)
-    else:
-        cursor.execute("""
-            SELECT      q.id as queue,
-                        q.title AS name,
-                        COUNT(CASE t.status WHEN '1' THEN t.id WHEN '2' THEN t.id END) AS open,
-                        COUNT(CASE t.status WHEN '3' THEN t.id END) AS resolved,
-                        COUNT(CASE t.status WHEN '4' THEN t.id END) AS closed
-                FROM    helpdesk_queue q
-                LEFT OUTER JOIN helpdesk_ticket t
-                ON      q.id = t.queue_id            
-                GROUP BY queue, name
-                ORDER BY q.id;
-        """)    
-    
+    cursor.execute("""
+        SELECT      q.id as queue,
+                    q.title AS name,
+                    COUNT(CASE t.status WHEN '1' THEN t.id WHEN '2' THEN t.id END) AS open,
+                    COUNT(CASE t.status WHEN '3' THEN t.id END) AS resolved,
+                    COUNT(CASE t.status WHEN '4' THEN t.id END) AS closed
+            FROM    helpdesk_ticket t,
+                    helpdesk_queue q
+            WHERE   q.id = t.queue_id
+            GROUP BY queue, name
+            ORDER BY q.id;
+    """)
     
     dash_tickets = query_to_dict(cursor.fetchall(), cursor.description)
 
@@ -272,7 +254,6 @@ def view_ticket(request, ticket_id):
             'active_users': users,
             'priorities': Ticket.PRIORITY_CHOICES,
             'preset_replies': PreSetReply.objects.filter(Q(queues=ticket.queue) | Q(queues__isnull=True)),
-            'tags_enabled': HAS_TAG_SUPPORT,
             'ticketcc_string': ticketcc_string,
             'SHOW_SUBSCRIBE': SHOW_SUBSCRIBE,
         }))
@@ -346,7 +327,6 @@ def update_ticket(request, ticket_id, public=False):
         else:
             due_date = timezone.now()
         due_date = due_date.replace(due_date_year, due_date_month, due_date_day)
-    tags = request.POST.get('tags', '')
 
     no_changes = all([
         not request.FILES,
@@ -356,7 +336,6 @@ def update_ticket(request, ticket_id, public=False):
         priority == int(ticket.priority),
         due_date == ticket.due_date,
         (owner == -1) or (not owner and not ticket.assigned_to) or (owner and User.objects.get(id=owner) == ticket.assigned_to),
-        (HAS_TAG_SUPPORT and tags == ticket.tags) or not HAS_TAG_SUPPORT,
     ])
     if no_changes:
         return return_to_ticket(request.user, helpdesk_settings, ticket)
@@ -463,17 +442,6 @@ def update_ticket(request, ticket_id, public=False):
         c.save()
         ticket.due_date = due_date
 
-    if HAS_TAG_SUPPORT:
-        if tags != ticket.tags:
-            c = TicketChange(
-                followup=f,
-                field=_('Tags'),
-                old_value=ticket.tags,
-                new_value=tags,
-                )
-            c.save()
-            ticket.tags = tags
-
     if new_status in [ Ticket.RESOLVED_STATUS, Ticket.CLOSED_STATUS ]:
         if new_status == Ticket.RESOLVED_STATUS or ticket.resolution is None:
             ticket.resolution = comment
@@ -745,7 +713,7 @@ def ticket_list(request):
             or  request.GET.has_key('q')
             or  request.GET.has_key('sort')
             or  request.GET.has_key('sortreverse') 
-            or  request.GET.has_key('tags') ):
+                ):
 
         # Fall-back if no querying is being done, force the list to only
         # show open/reopened/resolved (not closed) cases sorted by creation
@@ -821,13 +789,6 @@ def ticket_list(request):
         }
         ticket_qs = apply_query(Ticket.objects.select_related(), query_params)
 
-    ## TAG MATCHING
-    if HAS_TAG_SUPPORT:
-        tags = request.GET.getlist('tags')
-        if tags:
-            ticket_qs = TaggedItem.objects.get_by_model(ticket_qs, tags)
-            query_params['tags'] = tags
-
     ticket_paginator = paginator.Paginator(ticket_qs, request.user.usersettings.settings.get('tickets_per_page') or 20)
     try:
         page = int(request.GET.get('page', '1'))
@@ -853,10 +814,6 @@ def ticket_list(request):
     querydict = request.GET.copy()
     querydict.pop('page', 1)
 
-    tag_choices = [] 
-    if HAS_TAG_SUPPORT:
-        # FIXME: restrict this to tags that are actually in use
-        tag_choices = Tag.objects.all()
 
     return render_to_response('helpdesk/ticket_list.html',
         RequestContext(request, dict(
@@ -866,14 +823,12 @@ def ticket_list(request):
             user_choices=User.objects.filter(is_active=True,is_staff=True),
             queue_choices=Queue.objects.all(),
             status_choices=Ticket.STATUS_CHOICES,
-            tag_choices=tag_choices,
             urlsafe_query=urlsafe_query,
             user_saved_queries=user_saved_queries,
             query_params=query_params,
             from_saved_query=from_saved_query,
             saved_query=saved_query,
             search_message=search_message,
-            tags_enabled=HAS_TAG_SUPPORT
         )))
 ticket_list = staff_member_required(ticket_list)
 
@@ -891,7 +846,6 @@ def edit_ticket(request, ticket_id):
     return render_to_response('helpdesk/edit_ticket.html',
         RequestContext(request, {
             'form': form,
-            'tags_enabled': HAS_TAG_SUPPORT,
         }))
 edit_ticket = staff_member_required(edit_ticket)
 
@@ -924,7 +878,6 @@ def create_ticket(request):
     return render_to_response('helpdesk/create_ticket.html',
         RequestContext(request, {
             'form': form,
-            'tags_enabled': HAS_TAG_SUPPORT,
         }))
 create_ticket = staff_member_required(create_ticket)
 
